<?php

define("EVERLIGHTBOX_FABBAR_VERSION", "1.0.0");

class Everlightbox_Facebook_Sidebar {

	protected $options = null;

	public function __construct( ) {
		add_filter( 'everlightbox_additional_fields', array($this, 'add_field'));
		add_filter( 'everlightbox_additional_tabs', array($this, 'tabs'));
		add_filter( 'everlightbox_css_classes', array($this, 'add_css_classes'));

		$this->options = get_option('everlightbox_options');

		if(isset($this->options["comment_sidebar_enabled"]) && $this->options["comment_sidebar_enabled"])
		{
			add_action( 'wp_enqueue_scripts', array($this, 'enqueue_script'), 9 );
			add_action( 'wp_footer', array($this, 'footer'), 10 );
			add_action( 'wp_head', array($this, 'header'), 15 );		
		}		
	}

	public  function tabs($tabs) {
		$tabs->add("comment_sidebar", "Comment sidebar");
	}

	public function add_css_classes($css) {		
		return $css . " sidebar-comment sidebar-comment-facebook";
	}

	public function add_field($options) {

		$options->add_field( array(
			'name' => 'Enable',
			'desc' => 'Enable comments sidebar',
			'id'   => 'comment_sidebar_enabled',
			'type' => 'checkbox',
			'row_classes' => 'el-tab-comment_sidebar'
		) );

		$options->add_field( array(
			'name' => 'Sidebar width',
			'desc' => 'Set the width (pixels) of the sidebar',
			'id'   => 'comment_sidebar_width',
			'type' => 'text_small',
			'default' 	  => '400',
			'row_classes' => 'el-tab-comment_sidebar'
		) );

		$options->add_field( array(
		    'name'    => 'Color scheme',
		    'desc'	  => 'Facebook doesn\'t allow changing the font color, you can choose between a light and a dark color scheme',
		    'id'      => 'comment_sidebar_colscheme',
		    'type'    => 'select',
		    'show_option_none' => false,
		    'default' => 'light',
		    'options' => array(
		        'light'  => __( 'Light', 'cmb2' ),
		        'dark'   => __( 'Dark', 'cmb2' )
		    ),
		    'row_classes' => 'el-tab-comment_sidebar'
		) );

		$options->add_field( array(
		    'name'    => 'Background color',
		    'desc' 	  => 'Set the background color of the sidebar',
		    'id'      => 'comment_sidebar_bgcol',
		    'type'    => 'colorpicker',
		    'default' => '#ffffff',
		    'row_classes' => 'el-tab-comment_sidebar'
		) );

		return $options;
	}

	public function enqueue_script() {
		wp_register_script( 'everlightbox-comment-sidebar', EVERLIGHTBOX_URL . 'includes-premium/js/everlightbox-comment-sidebar.js', array( 'jquery', 'everlightbox' ), EVERLIGHTBOX_FABBAR_VERSION, true );
		wp_enqueue_script( 'everlightbox-comment-sidebar' );

		wp_register_style('everlightbox-comment-sidebar', EVERLIGHTBOX_URL . 'includes-premium/css/everlightbox-comment-sidebar.css', array('everlightbox'), EVERLIGHTBOX_FABBAR_VERSION);
        wp_enqueue_style('everlightbox-comment-sidebar');
	}

	public function header() {
		$width = 400;
		if(! empty($this->options['comment_sidebar_width']))
			$width = $this->options['comment_sidebar_width'];

		$colscheme = "light";
		if(! empty($this->options['comment_sidebar_colscheme']))
			$colscheme = $this->options['comment_sidebar_colscheme'];

		$bgcol = "#fff";
		if(! empty($this->options['comment_sidebar_bgcol']))
			$bgcol = $this->options['comment_sidebar_bgcol'];		

		?>
		<script>
		var __everlightbox_sidebar_comment_width = <?php echo $width ?>;
		var __everlightbox_sidebar_comment_colorscheme = "<?php echo $colscheme ?>";
		</script>

		<style>
			@media all and (min-width: 1024px) {
				#everlightbox-slider .slide img {
					border-top-right-radius: 0;
					border-bottom-right-radius: 0;
					margin-left: -<?php echo $width ?>px;
					max-width: calc(<?php echo $this->options['max_width'] ?>% - <?php echo $width ?>px - 75px);
				}
				#everlightbox-slider .slide .everlightbox-sidebar {
					border-top-right-radius: 4px;
					border-bottom-right-radius: 4px;
					background-color: <?php echo $bgcol ?>;
				}
			}
		</style>

		<?php
	}

	public function footer() { 	?>

		
		<?php
	}
}

$everlightboxCommentSidebar = new Everlightbox_Facebook_Sidebar();
